summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorajay priyadarshi <ajay.priyadarshi@ril.com>2018-02-23 17:36:01 +0530
committerajay priyadarshi <ajay.priyadarshi@ril.com>2018-02-23 17:36:01 +0530
commit183e9cdb3c7374a8f97431dfe1a8cdb7a40a9b19 (patch)
treebc6b0b6e6ed43e333bb126a840fa0b33f77c1bd0
parent6976625e7fa87f70e099328944c330703c36c274 (diff)
Variable updated in src and test files
file name: CollectMsgReceiverThread.java, CollectMsgReceiverThreadTest.java Change-Id: Ic2b6679e254e469a3f25024a9b6b9bdeb6b19af8 Issue-ID: VFC-777 Signed-off-by: ajay priyadarshi <ajay.priyadarshi@ril.com>
-rw-r--r--ems/boco/src/main/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThread.java16
-rw-r--r--ems/boco/src/test/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThreadTest.java8
2 files changed, 12 insertions, 12 deletions
diff --git a/ems/boco/src/test/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThreadTest.java b/ems/boco/src/test/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThreadTest.java
index c836cf6..a120021 100644
--- a/ems/boco/src/test/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThreadTest.java
+++ b/ems/boco/src/test/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThreadTest.java
@@ -46,8 +46,8 @@ public class CollectMsgReceiverThreadTest {
col.setRun(true);
col.dispose();
col.getTaskService().stopTask();
- col.getThread_max_num();
- col.setThread_max_num(1);
+ col.getThreadMaxNum();
+ col.setThreadMaxNum(1);
}
@@ -67,8 +67,8 @@ public class CollectMsgReceiverThreadTest {
col.setRun(true);
col.dispose();
col.getTaskService().stopTask();
- col.getThread_max_num();
- col.setThread_max_num(1);
+ col.getThreadMaxNum();
+ col.setThreadMaxNum(1);
}
}
diff --git a/ems/boco/src/main/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThread.java b/ems/boco/src/main/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThread.java
index f53a5ed..d3ced48 100644
--- a/ems/boco/src/main/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThread.java
+++ b/ems/boco/src/main/java/org/onap/vfc/nfvo/emsdriver/collector/CollectMsgReceiverThread.java
@@ -29,14 +29,14 @@ public class CollectMsgReceiverThread extends DriverThread {
private TaskThreadService taskService;
- private int thread_max_num = 100;
+ private int threadMaxNum = 100;
@Override
public void dispose() {
collectChannel = MessageChannelFactory.getMessageChannel(Constant.COLLECT_CHANNEL_KEY);
- taskService = TaskThreadService.getInstance(thread_max_num);
+ taskService = TaskThreadService.getInstance(threadMaxNum);
taskService.start();
while (isRun()) {
@@ -71,18 +71,18 @@ public class CollectMsgReceiverThread extends DriverThread {
/**
- * @return the thread_max_num
+ * @return the threadMaxNum
*/
- public int getThread_max_num() {
- return thread_max_num;
+ public int getThreadMaxNum() {
+ return threadMaxNum;
}
/**
* @param thread_max_num the thread_max_num to set
*/
- public void setThread_max_num(int thread_max_num) {
- this.thread_max_num = thread_max_num;
+ public void setThreadMaxNum(int threadMaxNum) {
+ this.threadMaxNum = threadMaxNum;
}
@@ -71,18 +71,18 @@ public class CollectMsgReceiverThread extends DriverThread {
}
/**
- * @param thread_max_num the thread_max_num to set
+ * @param threadMaxNum the threadMaxNum to set
*/